pub fn anchor_summary(projected: &[(i64, Vec<f32>)]) -> AnchorSummaryExpand description
Compute summary statistics of anchor proximity over a trajectory.
pub fn anchor_summary(projected: &[(i64, Vec<f32>)]) -> AnchorSummaryCompute summary statistics of anchor proximity over a trajectory.