Struct AnchorSpaceIndex

pub struct AnchorSpaceIndex {
    config: AnchorSetConfig,
    k: usize,
    projected_vectors: Vec<Vec<f32>>,
    source_model: Vec<u32>,
    entity_ids: Vec<u64>,
    timestamps: Vec<i64>,
    entity_index: BTreeMap<u64, Vec<(i64, u32)>>,
}
An index operating in anchor-projected space (ℝᴷ).

Stores pre-projected vectors from potentially multiple embedding models. All comparable because they use the same anchor set.

Fields

config: AnchorSetConfig

Anchor set configuration.

k: usize

Number of anchors (= dimensionality of projected space).

projected_vectors: Vec<Vec<f32>>

Projected vectors: node_id → Vec of length K.

source_model: Vec<u32>

Source model identifier per node.

entity_ids: Vec<u64>

Entity ID per node.

timestamps: Vec<i64>

Timestamp per node.

entity_index: BTreeMap<u64, Vec<(i64, u32)>>

Entity index: entity_id → sorted vec of (timestamp, node_id).

Implementations

Source

impl AnchorSpaceIndex

pub fn new(config: AnchorSetConfig, k: usize) -> Self

Create a new empty anchor space index.

pub fn insert( &mut self, entity_id: u64, timestamp: i64, vector: &[f32], model_anchors: &[&[f32]], model_id: u32, ) -> u32

Insert a raw vector, projecting it to anchor space.

model_anchors are the anchor vectors embedded in the SAME model as the input vector. These may differ from anchors of other models.

pub fn insert_projected( &mut self, entity_id: u64, timestamp: i64, projected: Vec<f32>, model_id: u32, ) -> u32

Insert a pre-projected vector (already in ℝᴷ).

pub fn search( &self, query_projected: &[f32], k: usize, filter: TemporalFilter, ) -> Vec<(u32, f32)>

Search in anchor space: flat scan kNN by L2 distance in ℝᴷ.

Cross-model: results may come from ANY source model.

pub fn trajectory( &self, entity_id: u64, filter: TemporalFilter, ) -> Vec<(i64, Vec<f32>)>

Retrieve trajectory in anchor space for an entity.

pub fn cross_model_trajectory( &self, entity_id: u64, filter: TemporalFilter, ) -> BTreeMap<u32, Vec<(i64, Vec<f32>)>>

Cross-model trajectory: separate trajectories per source model.

pub fn anchor_drift( &self, entity_id: u64, t1: i64, t2: i64, ) -> Option<AnchorDriftReport>

Compute drift in anchor space between two timestamps.

pub fn len(&self) -> usize

Number of indexed points.

pub fn is_empty(&self) -> bool

Whether the index is empty.

pub fn n_entities(&self) -> usize

Number of unique entities.

pub fn entity_id(&self, node_id: u32) -> u64

Get entity ID for a node.

pub fn timestamp(&self, node_id: u32) -> i64

Get timestamp for a node.

pub fn source_model(&self, node_id: u32) -> u32

Get source model for a node.

pub fn projected_vector(&self, node_id: u32) -> &[f32]

Get projected vector for a node.

pub fn config(&self) -> &AnchorSetConfig

Anchor set config.

pub fn k(&self) -> usize

Dimensionality of the projected space (= number of anchors).

pub fn save(&self, path: &Path) -> Result<()>

Save to file via postcard.

pub fn load(path: &Path) -> Result<Self>

Load from file.