fn merge_group_results(results: &mut Vec<GroupJoinResult>, step: i64)Expand description
Merge consecutive group join results that overlap in time.
fn merge_group_results(results: &mut Vec<GroupJoinResult>, step: i64)Merge consecutive group join results that overlap in time.